<?php
/**
 * This file contains the functions that affect tha page output
 */
/**
 * Function for handling what the browser/search engine title should be. Attempts to handle every 
 * possible situation WordPress throws at it for the best optimization.
 *
 * @since 6.0
 * @global $wp_query
 */
function swift_document_title() {
	global $wp_query;

	/* Set up some default variables. */
	$doctitle = '';
	$separator = ':';

	/* If viewing the front page and posts page of the site. */
	if ( is_front_page() && is_home() )
		$doctitle = get_bloginfo( 'name' ) . $separator . ' ' . get_bloginfo( 'description' );

	/* If viewing the posts page or a singular post. */
	elseif ( is_home() || is_singular() ) {
		$post_id = $wp_query->get_queried_object_id();

		$doctitle = get_post_meta( $post_id, 'Title', true );

		if ( empty( $doctitle ) && is_front_page() )
			$doctitle = get_bloginfo( 'name' ) . $separator . ' ' . get_bloginfo( 'description' );

		elseif ( empty( $doctitle ) )
			$doctitle = get_post_field( 'post_title', $post_id );
	}

	/* If viewing any type of archive page. */
	elseif ( is_archive() ) {

		/* If viewing a taxonomy term archive. */
		if ( is_category() || is_tag() || is_tax() ) {

			if ( function_exists( 'single_term_title' ) ) {
				$doctitle = single_term_title( '', false );
			} else { // 3.0 compat
				$term = $wp_query->get_queried_object();
				$doctitle = $term->name;
			}
		}

		/* If viewing a post type archive. */
		elseif ( function_exists( 'is_post_type_archive' ) && is_post_type_archive() ) {
			$post_type = get_post_type_object( get_query_var( 'post_type' ) );
			$doctitle = $post_type->labels->name;
		}

		/* If viewing an author/user archive. */
		elseif ( is_author() )
			$doctitle = get_the_author_meta( 'display_name', get_query_var( 'author' ) );

		/* If viewing a date-/time-based archive. */
		elseif ( is_date () ) {
			if ( get_query_var( 'minute' ) && get_query_var( 'hour' ) )
				$doctitle = sprintf( __( 'Archive for %1$s', 'swift' ), get_the_time( __( 'g:i a', 'swift' ) ) );

			elseif ( get_query_var( 'minute' ) )
				$doctitle = sprintf( __( 'Archive for minute %1$s', 'swift' ), get_the_time( __( 'i', 'swift' ) ) );

			elseif ( get_query_var( 'hour' ) )
				$doctitle = sprintf( __( 'Archive for %1$s', 'swift' ), get_the_time( __( 'g a', 'swift' ) ) );

			elseif ( is_day() )
				$doctitle = sprintf( __( 'Archive for %1$s', 'swift' ), get_the_time( __( 'F jS, Y', 'swift' ) ) );

			elseif ( get_query_var( 'w' ) )
				$doctitle = sprintf( __( 'Archive for week %1$s of %2$s', 'swift' ), get_the_time( __( 'W', 'swift' ) ), get_the_time( __( 'Y', 'swift' ) ) );

			elseif ( is_month() )
				$doctitle = sprintf( __( 'Archive for %1$s', 'swift' ), single_month_title( ' ', false) );

			elseif ( is_year() )
				$doctitle = sprintf( __( 'Archive for %1$s', 'swift' ), get_the_time( __( 'Y', 'swift' ) ) );
		}
	}

	/* If viewing a search results page. */
	elseif ( is_search() )
		$doctitle = sprintf( __( 'Search results for &quot;%1$s&quot;', 'swift' ), esc_attr( get_search_query() ) );

	/* If viewing a 404 not found page. */
	elseif ( is_404() )
		$doctitle = __( '404 Not Found', 'swift' );

	/* If the current page is a paged page. */
	if ( ( ( $page = $wp_query->get( 'paged' ) ) || ( $page = $wp_query->get( 'page' ) ) ) && $page > 1 )
		$doctitle = sprintf( __( '%1$s Page %2$s', 'swift' ), $doctitle . $separator, number_format_i18n( $page ) );

	/* Apply the wp_title filters so we're compatible with plugins. */
	echo apply_filters( 'wp_title', $doctitle, $separator, '' );
}


function swift_meta_generator( $meta, $classes ) {
	$data = '<div class="entry-meta '.$classes.'">';
	$size = count($meta);
	for($i=0;$i<$size;$i++){
		switch ( $meta[$i] ){
			case 'text':
				$data .= $meta[$i+1];
				$i++;
			break;
				
			case 'author':
				$data .= '<span class="author"><a href="'.esc_url(get_author_posts_url( get_the_author_meta( 'ID' ) )).'" rel="author">'.esc_attr(get_the_author()).'</a></span> ';
			break;
				
			case 'date':
				$data .='<span class="date"><a href="'.esc_url( get_permalink() ).'" title="'.esc_attr( get_the_time() ).'" rel="bookmark">';
				$data .= '<time class="entry-date" datetime="'.esc_attr( get_the_date( 'c' ) ).'" pubdate>'.esc_html( get_the_date() ).'</time></a></span> ';
			break;	

			case 'categories':
				$data .= get_the_category_list( ', ' );
			break;
		}
	}
	echo $data.'</div>';
}

if ( ! function_exists( 'swift_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 * Create your own swift_posted_on to override in a child theme
 *
 * @since Swift 6.0
 */
function swift_posted_on() {
	printf( __( '<span class="entry-meta posted-on"><span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a><span class="by-author"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span></span>', 'swift' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		sprintf( esc_attr__( 'View all posts by %s', 'swift' ), get_the_author() ),
		esc_html( get_the_author() )
	);
}
endif;

if( ! function_exists( 'swift_filed_under' ) ):
/**
 * Prints HTML for the cureent post categories.
 * Create your own swift_filed_under to override in a child theme
 */
function  swift_filed_under() {
?>	<span class="single-entry-meta filed-under"><?php _e( 'Filed under', 'swift' )?> <span class="uppercase"><?php the_category( ', ' )?></span></span>
<?php
}
endif;

if( ! function_exists( 'swift_tagged_with' ) ):
/**
 * Prints HTML for the cureent post tags.
 * Create your own swift_tagged_with to override in a child theme
 */
function  swift_tagged_with() {
?>	<span class="single-entry-meta tagged-with"><?php _e( 'Tagged with', 'swift' )?> <span class="uppercase"><h6><?php the_tags('', ', ', ' '); ?></h6></span></span>
<?php
}
endif;
?>
<?php 
add_action( 'wp_head', 'swift_header_scripts');
function swift_header_scripts(){
	$temp = get_option('swift_options');
	if ( isset( $temp['header_scripts'] ) && $temp['header_scripts'] ) echo stripslashes( $temp['header_scripts'] );
}
?>
<?php 
add_action( 'wp_footer', 'swift_footer_scripts');
function swift_footer_scripts(){
	$temp = get_option('swift_options');
	if ( isset( $temp['footer_scripts'] ) && $temp['footer_scripts'] ) echo stripslashes( $temp['footer_scripts'] );
}
?>
<?php 
add_action( 'swift_before_header', 'swift_before_header_ad');
function swift_before_header_ad(){
	if( isset( $swift_options['above_header_ad_enable'] ) && $swift_options['above_header_ad_enable'] && isset( $swift_options['above_header_ad'] ) && $swift_options['above_header_ad'] != ''){?>
		<div id="nav-ad-container">
		<div class="div-content hybrid">
		<?php echo stripslashes( $swift_options['above_header_ad_enable'] )?>
		</div>
		</div>
<?php 
	}
}
?>
<?php 
/**
 * Hooking fucntions to swift_after_header_open
 */

add_action( 'swift_header', 'swift_nav_above_logo', 10 );
function swift_nav_above_logo(){
	GLOBAL $swift_options;
	
	if( has_nav_menu( 'above-logo' ) ): 
?>		<div id="above-logo-container">
		<nav id="above-logo" class="hybrid" role="navigation">
			<?php wp_nav_menu( array( 'theme_location' => 'above-logo', 'container' => false, 'menu_class' => 'nav clearfix', 'items_wrap' => '<ul class="%2$s">%3$s', ) ); ?>
		    <?php if( isset( $swift_options['rss_links_enable'] ) && $swift_options['rss_links_enable'] == true ) get_template_part( 'lib/includes/rss-links' );?>
			</ul>
		 </nav>
		</div>
<?php 
	endif; 	
}
?>
<?php 
add_action( 'swift_header', 'swift_branding', 15 );
function swift_branding(){
GLOBAL $swift_options;
?>
		<div id="branding-container">
			<div id="branding" class="clearfix hybrid">
			<div class="div-content">
			<?php swift_before_branding()?>
			
<?php 
			if( isset($swift_options['logo'] ) && $swift_options['logo'] != ''){
?>			<a href="<?php echo home_url(); ?>" title="<?php bloginfo( 'description' ); ?>"><img src="<?php echo $swift_options['logo']?>" alt="<?php bloginfo( 'name' ); ?>" id="logo"  /></a>
<?php 
		          
			}elseif( is_front_page() || is_home() ){
?>			<hgroup class="alignleft">
				<h1 id="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				<h2 id="site-description"><?php bloginfo( 'description' ); ?></h2>
			</hgroup>
<?php 	
			}else{
?>			<hgroup class="alignleft">
				<h2 id="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h2>
				<h3 id="site-description"><?php bloginfo( 'description' ); ?></h3>
			</hgroup>
			
<?php 
			}
?>

			
			<?php swift_after_branding()?>
			</div>
			</div><!-- /branding -->
		</div>
		<div class="clear"></div>
<?php }
?>
<?php 
add_action( 'swift_header', 'swift_nav_below_logo', 20 );
function  swift_nav_below_logo(){
	GLOBAL $swift_options;
	if( has_nav_menu( 'below-logo' ) ): 
?>		<div id="below-logo-container">
		<nav id="below-logo" class="hybrid" role="navigation">
			<?php wp_nav_menu( array( 'theme_location' => 'below-logo', 'container' => false, 'menu_class' => 'nav clearfix', 'items_wrap' => '<ul class="%2$s">%3$s', ) ); ?>
		 <?php if( isset( $swift_options['nav_search_enable'] ) && $swift_options['nav_search_enable'] == true) 	get_template_part( 'searchform-nav' );?>
		 </ul>
    </nav>
		</div>
<?php 
	endif;
}
?>
<?php 
add_action( 'swift_after_branding', 'swift_header_ad', 12 );
function swift_header_ad(){
	GLOBAL $swift_options;
	if( isset( $swift_options['header_ad_enable'] ) && $swift_options['header_ad_enable'] && isset( $swift_options['header_ad'] ) && $swift_options['header_ad'] != ''){?>
		<div id="header-ad" class="alignright">
		<?php echo stripcslashes( $swift_options['header_ad'] )?>
		</div>
<?php 
	}
}

add_filter( 'the_content', 'swift_single_ads', 16 );
function swift_single_ads( $content ){
	if( !is_single() || is_attachment() )
	return  $content;
	GLOBAL $swift_options;
	
	if( isset( $swift_options['between_content_ad_enable'] ) && $swift_options['between_content_ad_enable'] && isset( $swift_options['between_content_ad'] ) && $swift_options['between_content_ad'] != ''){
		
		$temp = explode('</p>', $content);
		$add_after = (int)(count($temp)/2);
		$content = NULL;
		
		for($i=0;$i<count($temp);$i++){
			$content .= $temp[$i].'</p>';
			if($i+1==$add_after){
				$content .= stripslashes($swift_options['between_content_ad']);	
			}
		}

	}
	
	if( isset( $swift_options['before_content_ad_enable'] ) && $swift_options['before_content_ad_enable'] && isset( $swift_options['before_content_ad'] ) && $swift_options['before_content_ad'] != ''){
		$content = stripslashes($swift_options['before_content_ad']).$content;
	}
	
	if( isset( $swift_options['after_content_ad_enable'] ) && $swift_options['after_content_ad_enable'] && isset( $swift_options['after_content_ad'] ) && $swift_options['after_content_ad'] != ''){
		$content = $content.stripslashes($swift_options['after_content_ad']);
	}	
	return $content;
}
	
add_filter( 'post_thumbnail_html', 'swift_post_image_html', 10, 5 );

function swift_post_image_html($html, $post_id, $post_thumbnail_id, $size, $attr) { 
	global $swift_options;	
		global $_wp_additional_image_sizes;
	if( $html != '' ){
		$html = '<a href="' . get_permalink( $post_id ) . '" title="' . esc_attr( get_post_field( 'post_title', $post_id ) ) . '">' . $html . '</a>';
		return $html;
	}
	elseif( isset($swift_options['default_thumb'] )  && $swift_options['default_thumb'] != "" ){
		$html = '<a href="' . get_permalink( $post_id ) . '" title="' . esc_attr( get_post_field( 'post_title', $post_id ) ) . '">
		<img src="'.$swift_options['default_thumb'].'" class="'.$attr['class'].'" width="'.$size[0].'" height="'.($size[0]/1.62).'" title="#post_'.$post_id.'"/></a>';
		return $html;
		
	}
}

/**
 * code taken from http://wordpress.stackexchange.com/questions/13044/how-can-i-add-title-attributes-to-next-and-previous-post-link-functions/21987#21987
 */

add_filter('next_post_link','swift_add_title_to_next_post_link');
function swift_add_title_to_next_post_link($link) {
global $post;
$post = get_post($post_id);
$next_post = get_next_post();
$title = $next_post->post_title;
$link = str_replace("rel=", " title='".$title."' rel", $link);
return $link;
}

add_filter('previous_post_link','swift_add_title_to_previous_post_link');
function swift_add_title_to_previous_post_link($link) {
global $post;
$post = get_post($post_id);
$previous_post = get_previous_post();
$title = $previous_post->post_title;
$link = str_replace("rel=", " title='".$title."' rel", $link);
return $link;
}
//add_action('wp_footer', 'swift_share_buttons');
function swift_share_buttons(){
GLOBAL $swift_options;
	if( ! isset($swift_options['social_share_enable']) || ! $swift_options['social_share_enable'] || !is_single() || is_front_page() )
	return;
?>
<div id="share-post"> 
<ul class="share-post clearfix">
<li>
<a class="DiggThisButton DiggCompact"></a>
</li>
<li>
<a href="http://twitter.com/share" class="twitter-share-button" data-count="horizontal" data-via="<?php echo $swift_options['sm_twitter']?>">Tweet</a><script type="text/javascript" src="http://platform.twitter.com/widgets.js"  defer="defer"></script>
</li>
<!-- Place this tag where you want the +1 button to render -->
<li>
<div class="g-plusone" data-size="medium"></div>

<!-- Place this render call where appropriate -->
<script type="text/javascript">
  (function() {
    var po = document.createElement('script'); po.type = 'text/javascript'; po.async = true;
    po.src = 'https://apis.google.com/js/plusone.js';
    var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(po, s);
  })();
</script>
</li>

<li style="margin-top:0px"><div id="fb-root"></div>
<script type="text/javascript">(function(d, s, id) {
  var js, fjs = d.getElementsByTagName(s)[0];
  if (d.getElementById(id)) {return;}
  js = d.createElement(s); js.id = id;
  js.src = "//connect.facebook.net/en_US/all.js#xfbml=1&appId=275401355811523";
  fjs.parentNode.insertBefore(js, fjs);
}(document, 'script', 'facebook-jssdk'));</script>

<div class="fb-like" data-send="true" data-layout="button_count" data-width="140" data-show-faces="false" data-font="arial"></div>

</li>

</ul>
<div class="clear"></div>
</div><?php 
}
?>